     ///////////////////////////////////////////////
    // THE CONSTRAINT-UNDERSTANDING SYSTEM        //
   // Written by Andrew Broad                    ///
  //                                            ////
 // OrderedVector.java (1998:10:27 11:32)      /////
////////////////////////////////////////////////////
// Methods of OrderedVector:                   /////
// - OrderedVector constructor()               /////
// - OrderedVector constructor(Object[])       /////
// - OrderedVector constructor(Object[],Frame) ////
// - toString                                  ///
// - FILise                                    //
////////////////////////////////////////////////

import java.io.*;
import java.util.*;
import express.*;

/*******************************************************************************
** The class `OrderedVector' is a subclass of vectors that represent lists or
** arrays in the frame system.
*******************************************************************************/

public class OrderedVector extends Vector {

	/**********************************************************************/
	// OrderedVector constructor : void ->
	/***********************************************************************
	** Constructs an empty ordered vector.
	***********************************************************************/
 
 	public OrderedVector () {
		super();
	}
	
	/**********************************************************************/
	// OrderedVector constructor : Object[] ->
	/***********************************************************************
	** Constructs an ordered vector from an exjava array, converting the
	** elements to their corresponding values for the frame system.
	** @param array The array of objects to construct the vector from.
	***********************************************************************/
 
 	public OrderedVector (Object[] array) {
 		super();
 		
		for (int i= 0; i < array.length; i++)
			addElement(Values.convert(array[i]));
	}

	/**********************************************************************/
	// OrderedVector constructor : (Object[] x Frame) ->
	/***********************************************************************
	** Constructs an ordered vector from an exjava array, converting the
	** elements to their corresponding values for the frame system. The
	** extra argument is an entity or defined type frame to be passed on to
	** Values.convert just in case the vector contains IdRefs (directly or
	** indirectly).
	** @param array The array of objects to construct the vector from.
	** @param entityorTypeFrame The entity or defined type frame to be
	**  passed to Values.convert.
	***********************************************************************/
 
 	public OrderedVector (Object[] array, Frame entityOrTypeFrame) {
 		super();
 		
		for (int i= 0; i < array.length; i++)
			addElement(Values.convert(array[i], entityOrTypeFrame));
	}

	/**********************************************************************/
	// OrderedVector.FILise : boolean -> String
	/***********************************************************************
	** Writes FIL for this ordered vector. Elements are enclosed in square
	** square brackets and separated by commas. Elements are FIL-ised
	** recursively.
	** @param HTML If true, FIL will be augmented with HTML tags.
	** @returns The FIL representation of this ordered vector.
	***********************************************************************/

	public String FILise (boolean HTML) {
		String agg= "[";

		for (int i= 0; i < size(); i++) {
			Object element= elementAt(i);
			if (element != null)
				agg+= Values.FILise(element,HTML);
			else
				agg+= "null";
			if (i < (size() - 1))
			agg+= ", ";
		}
		return agg + "]";
	}
}
